@@ -29,6 +29,20 @@ from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
 from Solgema.fullcalendar.interfaces import ISolgemaFullcalendarView, ISolgemaFullcalendarEvents, ISolgemaFullcalendarProperties, ISFBaseEventFields
 from Solgema.fullcalendar.browser.solgemafullcalendar_views import getTopic, getCriteriaItems, getColorIndex
 
+# Check for Plone versions
+try:
+   from plone.app.upgrade import v40
+   HAS_PLONE30 = True
+   HAS_PLONE40 = True
+except ImportError:
+   HAS_PLONE40 = False
+   try:
+       from Products.CMFPlone.migrations import v3_0
+   except ImportError:
+       HAS_PLONE30 = False
+   else:
+       HAS_PLONE30 = True
+
 def getCopyObjectsUID(REQUEST):
     if REQUEST is not None and REQUEST.has_key('__cp'):
         cp = REQUEST['__cp']
@@ -93,7 +107,10 @@ class SFDisplayAddMenu(BrowserView):
         pTypes = [a for a in getToolByName(self.context, 'portal_types').listTypeInfo() if a.id == portal_type]
         pTypeTitle = pTypes and pTypes[0].Title() or portal_type
         typeTitle = translate(pTypeTitle, context=self.request)
-        title = plMF(u'label_add_type', default='Add ${type}', mapping={'type' : typeTitle})
+        if HAS_PLONE40:
+            title = plMF(u'heading_add_item', default='Add ${itemtype}', mapping={'itemtype' : typeTitle})
+        else:
+            title = plMF(u'label_add_type', default='Add ${type}', mapping={'type' : typeTitle})
         return json.dumps({'display':False, 'type':portal_type, 'title':translate(title, context=self.request)})
 
 class SFAddMenu(BrowserView):
