@@ -388,7 +388,7 @@ function readCookie(name) {
         cook.push({'name':keys[x], 'value':value});
       }
       jq.each(cook, function(i,elem){
-        var path = window.location.pathname;
+        var path = SolgemaFullcalendarVars.topicRelativeUrl;
         if (path.substring(path.length-1,path.length)!='/') path =path+'/';
         document.cookie = elem.name+"="+elem.value+'; path='+path;
       });
@@ -399,7 +399,7 @@ function readCookie(name) {
       var classList = divClass.split(' ');
       for (var i=0; i<classList.length; i++) {
         if (classList[i].search('fc-button-') != -1){
-          var path = window.location.pathname;
+          var path = SolgemaFullcalendarVars.topicRelativeUrl;
           if (path.substring(path.length-1,path.length)!='/') path =path+'/';
           val = classList[i].substring(10, classList[i].length);
           document.cookie = "SFView="+val+'; path='+path;
@@ -409,3 +409,4 @@ function readCookie(name) {
   });
 
 
+
